@@ -19,8 +19,8 @@ import dbus.service
 import dbus.mainloop.glib
 
 from calculate.consolegui import qt
-# import sudsds, time, sys
 import time, sys
+import calculate.contrib
 from suds import MethodNotFound
 import os, pwd, shutil
 import ConfigParser
@@ -96,7 +96,6 @@ class SelectedMethodWgt(qt.QWidget):
                                      self.args.method + '_view', step = 0)
             view = self.ClientObj.client.service[0][self.args.method + \
                                 '_view'](int(self.ClientObj.sid), view_params)
-        # except sudsds.MethodNotFound:
         except MethodNotFound:
             _print('Method not found: ', self.args.method + '_view')
             self.close()
