@@ -23,8 +23,8 @@ def debug(level, *args):
         for s in args:
             print s,
         print
-# import urllib2, sudsds
 import urllib2
+import calculate.contrib
 from suds import MethodNotFound
 import re
 
@@ -256,7 +256,6 @@ class MainFrameRes(qt.QWidget):
                                        table.onClick + '_view', step = 0) #int(table.step) if table.step else 0)
                 view = self.client.service[0][table.onClick + '_view'](
                     sid, view_params)
-            # except sudsds.MethodNotFound, e:
             except MethodNotFound, e:
                 _print(e)
                 return
@@ -380,7 +379,6 @@ class MainFrameRes(qt.QWidget):
                                        self.method_name + '_view', step = None)
                 view = self.client.service[0][self.method_name + '_view'] \
                                                     (sid, view_params)
-            # except sudsds.MethodNotFound:
             except MethodNotFound:
                 return
             #if self._parent.ClientObj.method_names.has_key(self.method_name):
