@@ -21,10 +21,7 @@ if hasattr(u2,"ssl"):
 import os, re, sys
 from calculate.core.datavars import DataVarsCore
 
-# from sudsds.transport.http import HttpTransport, SUDSHTTPRedirectHandler, \
-#             CheckingHTTPSConnection, CheckingHTTPSHandler, \
-#             PYOPENSSL_AVAILABLE, PyOpenSSLSocket
-
+import calculate.contrib
 from suds.transport.http import HttpTransport
 
 try:
