@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 from calculate.consolegui import qt
-# from sudsds import WebFault
+import calculate.contrib
 from suds import WebFault
 import logging, OpenSSL
 import ConfigParser, os, urllib2
