@@ -83,3 +83,7 @@ QTimer = QtCore.QTimer
 QUrl = QtCore.QUrl
 Signal = QtCore.pyqtSignal
 
+#use that if you need to suppress QT warnings/errors
+def handler(msg_type, msg_log_context, msg_string):
+    pass
+QtCore.qInstallMessageHandler(handler)
\ No newline at end of file
